@@ -3,10 +3,11 @@ from __future__ import annotations
 from typing import Optional
 
 from ...core.utils import _Ensure
+from ...model.result import Result
 from ..argument import Args
 
 
-class TaskResult:
+class TaskResult(Result):
     def __init__(
         self,
         args: Args,
@@ -15,11 +16,17 @@ class TaskResult:
         success: Optional[bool] = None,
     ) -> None:
         self.args: Args = _Ensure.instance(args, Args, "args")
-        self.error: Optional[BaseException] = _Ensure.type(
-            error, BaseException, "error"
-        )
         self.message: Optional[str] = _Ensure.type(message, str, "message")
-        success = _Ensure.type(success, bool, "success")
-        self.success: bool = (
-            success if not success is None else (True if error is None else False)
+        super().__init__(
+            _Ensure.type(error, BaseException, "error"),
+            _Ensure.type(success, bool, "success"),
+        )
+
+    def __repr__(self) -> str:
+        return "{cls}(error={error}, success={success}, message={message}, args={args})".format(
+            cls=type(self).__name__,
+            error=self.error,
+            success=self.success,
+            message=self.message,
+            args=self.args,
         )
