@@ -1,8 +1,9 @@
 from __future__ import annotations
 
-from abc import ABC, abstractclassmethod, abstractmethod
+from abc import ABC, abstractmethod
 from typing import Iterable, List, Optional, Union
 
+from ...model.result import Result
 from ..argument import Args
 from .id import TaskId
 from .identity import TaskIdentity
@@ -27,6 +28,15 @@ class Task(ABC):
 
         TaskManager.print(message)
 
+    def _uptade_description(
+        self,
+        description: str,
+        result: Optional[Result] = None,  # Show some part had failed
+    ):
+        from ...core.task.manager import TaskManager
+
+        TaskManager.update_description(description, result)
+
     def _append_task(
         self, tasks: Union[Task, Iterable[Task], TaskIdentity, Iterable[TaskIdentity]]
     ) -> None:
