@@ -1,6 +1,6 @@
 from ...model.project import Project  # Will be used by children
 from ...model.task import *
-from ..options import ParseOptions
+from ..identity import AflutterTaskIdentity
 from ..project import ProjectRead, ProjectSave
 
 __all__ = [
@@ -11,14 +11,14 @@ __all__ = [
     "TaskId",
     "TaskIdentity",
     "TaskResult",
-    "Option",
     "Args",
+    "AflutterTaskIdentity",
 ]
 
 
 class _BaseConfigTask(Task):
     def require(self) -> List[TaskId]:
-        return [ProjectRead.identity.id, ParseOptions.identity.id]
+        return [ProjectRead.identity.id]
 
     def _add_save_project(self):
         self._append_task(ProjectSave())
