@@ -3,10 +3,11 @@ from json import dump as json_dump
 from ...core.json import _JsonEncode
 from ...model.project import Project
 from ...model.task import *
+from ...task.identity import AflutterTaskIdentity
 
 
 class ProjectSave(Task):
-    identity = TaskIdentity(
+    identity = AflutterTaskIdentity(
         "-project-save", "Saving project file", [], lambda: ProjectSave()
     )
 
